==========
intake-nwp
==========


Intake drivers for numerical weather prediction data
----------------------------------------------------

This package provides drivers for loading data from numerical weather using the
`herbie`_ library.


.. _herbie: https://github.com/blaylockbk/Herbie